from typing import Dict

METRIC_PREFIX = "databricks.ganglia"

class MintMetric:
    def __init__(
        self,
        key: str,
        value: float = None,
        value_type: str = None,
        dimensions: Dict[str, str] = None,
        unit: str = None
    ):
        self.key = f"{METRIC_PREFIX}.{key}"
        self.value = value
        self.value_type = value_type
        if dimensions is None:
            dimensions = {}
        self.dimensions = dimensions
        self.unit = unit

    def __hash__(self):
        return hash(self.key_and_dimension())

    def __eq__(self, other):
        return self.key_and_dimension() == other.key_and_dimension()

    def key_and_dimension(self):
        dimensions_string = ",".join([f'{k}="{v}"' for k, v in self.dimensions.items()])
        return f"{self.key},{dimensions_string}"

    def to_mint(self):
        if self.value_type == "gauge":
            value = f"gauge,{self.value}"
        elif self.value_type == "count":
            value = f"count,{self.value}"
        else:
            value = self.value
        return f"{self.key_and_dimension()} {value}"

    def to_mint_meta(self):
        return f'#{self.key} {self.value_type} dt.meta.unit="{self.unit}"'

    def __repr__(self):
        return self.to_mint()